@@ -18,8 +18,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef _NEPOMUK_RESOURCE_DATA_H_
-#define _NEPOMUK_RESOURCE_DATA_H_
+#ifndef _NEPOMUK2_RESOURCE_DATA_H_
+#define _NEPOMUK2_RESOURCE_DATA_H_
 
 #include <QtCore/QString>
 #include <QtCore/QList>
@@ -46,18 +46,22 @@ namespace Nepomuk2 {
         ~ResourceData();
 
         inline bool ref(Nepomuk2::Resource* res) {
-            // Should this lock m_modificationMutex first?
+            // Caller must lock ResourceManager mutex
             m_resources.push_back( res );
             return m_ref.ref();
         }
 
-
         inline bool deref(Nepomuk2::Resource* res) {
-            // Should this lock m_modificationMutex first?
+            // Caller must lock ResourceManager mutex
             m_resources.removeAll( res );
             return m_ref.deref();
         }
 
+        QList<Resource*> resources() const {
+            // Caller must lock ResourceManager mutex
+            return m_resources;
+        }
+
         inline int cnt() const {
             return m_ref;
         }
@@ -153,11 +157,6 @@ namespace Nepomuk2 {
 
         ResourceManagerPrivate* rm() const { return m_rm; }
 
-        /// Contains a list of resources which use this ResourceData
-        QList<Resource*> m_resources;
-
-        QHash<QUrl, Variant> m_cache;
-
         /// Updates ResourceManagerPrivate's list
         void updateKickOffLists( const QUrl& uri, const Variant& variant );
 
@@ -166,8 +165,10 @@ namespace Nepomuk2 {
         void propertyAdded( const Types::Property &prop, const QVariant &value );
 
     private:
-        void updateUrlLists( const QUrl& newUrl );
-        void updateIdentifierLists( const QString& string );
+        ResourceData(const ResourceData&); // = delete
+        ResourceData& operator = (const ResourceData&); // = delete
+        void updateUrlLists( const QUrl& oldUrl, const QUrl& newUrl );
+        void updateIdentifierLists( const QString& oldIdentifier, const QString& newIdentifier );
 
         void addToWatcher();
 
@@ -175,6 +176,9 @@ namespace Nepomuk2 {
         /// Used by remove() and deleteData()
         void resetAll( bool isDelete = false );
 
+        /// Contains a list of resources which use this ResourceData
+        QList<Resource*> m_resources;
+
         /// final resource URI created by determineUri
         KUrl m_uri;
 
@@ -195,6 +199,8 @@ namespace Nepomuk2 {
         // Never lock the ResourceManager mutex after locking this one. Always before (or not at all).
         mutable QMutex m_modificationMutex;
 
+        QHash<QUrl, Variant> m_cache;
+
         bool m_cacheDirty;
         bool m_addedToWatcher;
 
