@@ -98,6 +98,12 @@ bool Nepomuk2::Indexer::indexFile(const KUrl& url)
         uri = it[0].uri();
         mimeType = it[1].literal().toString();
     }
+    else {
+        SimpleIndexingJob* indexingJob = new SimpleIndexingJob( url );
+        indexingJob->exec();
+        uri = indexingJob->uri();
+        mimeType = indexingJob->mimeType();
+    }
 
     kDebug() << uri << mimeType;
     SimpleResourceGraph graph;
@@ -121,12 +127,12 @@ bool Nepomuk2::Indexer::indexFile(const KUrl& url)
             kError() << "SimpleIndexerError: " << job->errorString();
             return false;
         }
-
-        kDebug() << "Updating indexing level";
-        updateIndexingLevel( uri, 2 );
-        kDebug() << "Done";
     }
 
+    // Update the indexing level even if no data has changed
+    kDebug() << "Updating indexing level";
+    updateIndexingLevel( uri, 2 );
+
     return true;
 }
 
@@ -184,10 +190,11 @@ bool Nepomuk2::Indexer::indexFileDebug(const KUrl& url)
                 kError() << "SimpleIndexerError: " << job->errorString();
                 return false;
             }
-            kDebug() << "Updating the indexing level";
-            updateIndexingLevel( uri, 2 );
-            kDebug() << "Done";
         }
+
+        kDebug() << "Updating the indexing level";
+        updateIndexingLevel( uri, 2 );
+        kDebug() << "Done";
     }
 
     return status;
