@@ -34,6 +34,7 @@ class ClassAndPropertyTree;
 class ResourceMerger;
 class SimpleResourceGraph;
 class ResourceWatcherManager;
+class TypeCache;
 
 class DataManagementModel : public Soprano::FilterModel
 {
@@ -225,6 +226,13 @@ public Q_SLOTS:
                             const QList<QUrl>& targetParties = QList<QUrl>() ) const;
     //@}
 
+    /**
+     * Clear the internal cache present in the model
+     */
+    void clearCache();
+
+    TypeCache* typeCache();
+
 private:
     QUrl createGraph(const QString& app = QString(), const QHash<QUrl, QVariant>& additionalMetadata = (QHash<QUrl, QVariant>()));
     QUrl createGraph(const QString& app, const QMultiHash<QUrl, Soprano::Node>& additionalMetadata);
